%
% Estimate parameters for the A->B->C model using paresto.m
% jbr,  4/2018
%

%Model
% This m-file loads data file 'ABC_data.dat'.
model = struct;
model.nlp_solver_options.ipopt.linear_solver = 'ma27';
model.x = {'ca', 'cb', 'cc'};
model.p = {'k1', 'k2'};
model.d = {'m_ca', 'm_cb', 'm_cc'};


model.ode = @massbal_ode;

model.lsq = @(t, y, p) {y.ca-y.m_ca, y.cb-y.m_cb, y.cc-y.m_cc};

tfinal = 6;
nplot = 75;
tplot = linspace(0, tfinal, nplot)';

k1 = 2; k2 = 1;
p_ac = [k1; k2];

ca0 = 1; cb0 = 0; cc0 = 0;
x_ac = [ca0; cb0; cc0];

thetaic   = [0.5; 3; x_ac];
thetalb   = [1e-4; 1e-4; 0.9*x_ac];
thetaub   = [10; 10; 1.1*x_ac];
est_ind = 1:2;

% load measurements from a file
tabledat = load ('ABC_data.dat');
tmeas = tabledat(:,1);
ymeas = tabledat(:,2:4);

[tout,~,ic] = unique([tmeas; tplot]);
% index of times at which measurement is made
meas_ind = ic(1:numel(tmeas));
model.tout = tout;
% interploate measurement onto new grid
y_noisy = interp1(tmeas, ymeas, tout, 'previous');
y_noisy(isnan(y_noisy)) = 0.;
model.lsq_ind = meas_ind'; % only use index of measurement times in objective function

% Create a paresto instance
pe = paresto(model);

% estimate the parameters
est = pe.optimize(y_noisy', thetaic, thetalb, thetaub);

% Also calculate confidence intervals with 95 % confidence
theta_conf = pe.confidence(est, est_ind, 0.95);

disp('Estimated Parameters and Bounding Box')
[est.theta(est_ind)  theta_conf]

%plot the model fit to the noisy measurements
figure(1);
plot(model.tout, est.x, tmeas, ymeas', 'o');

% if 2-d, plot confidence ellipse
% if (length(objective.estflag) == 2)
%   [xe, ye] = ellipse(estimates.Pinv, estimates.b, 100, estimates.parest);
%   figure(2);
%   plot(xe, ye)
% end

tableest = [model.tout, est.x'];
save ABC.dat tableest tabledat