function xdot = benzene_pyrol_rhs(volume,x)
     global k1 K1 k2 K2 R T P NBf

     % Example in material balance chapter.
     % Data are:
     %           NBf = 60e3 mol/hr
     %           R  = 0.08205 lit atm/mol K
     %           T  = 1033 K
     %           P  = 1 atm
     %           k1 = 7e5 lit/mol hr
     %           k2 = 4e5 lit/mol hr
     %           K1 = 0.31
     %           K2 = 0.48
     %

     ext1 = x(1);
     ext2 = x(2);

     NB = NBf - 2*ext1 - ext2;
     ND = ext1 - ext2;
     NH = ext1 + ext2;
     NT = ext2;

     Q = NBf*R*T/P;

     cB = NB/Q;
     cD = ND/Q;
     cT = NT/Q;
     cH = NH/Q;

     xdot = [k1*(cB*cB - cD*cH/K1); k2*(cB*cD - cT*cH/K2)];
