
% Hepatitis B model, stochastic simulation.  Data and functions defined
% in this file are used in both hbv_stoch.m and hbv_binary.m

global k
k = [1; 0.025; 1000; 0.25; 2; 7.5e-6];
stoi = [0, 1, 0; 1, -1, 0; 0, 0, 1; -1, 0, 0; 0, 0, -1; 0, -1, -1];
x0  = [1; 0; 0];
stoiT = stoi';
tfin  = 200;
nts   = 200;
tout = linspace(0,tfin,nts)';
%
% steady state analysis
%
cas = ( k(1)-k(4) ) /   ...
      ( k(6) *k(4)/k(2)*( (-k(1)+k(4) +k(3)) / (k(5))) );
cbs = k(4)/k(2)* cas;
ccs = ( k(1)-k(4) ) / ( k(6) *k(4)/k(2) );
Jac = [-k(4), k(2), 0;
       k(1), -k(2)-k(6)*ccs, -k(6)*cbs;
       k(3), -k(6)*ccs, -k(5)-k(6)*cbs];
eig(Jac);

function rhs = hbv_deriv(t,x);
  global k
  rhs = zeros (3, 1);
  rhs(1) = k(2)*x(2) - k(4)*x(1);
  rhs(2) = k(1)*x(1) - k(2)*x(2) - k(6)*x(2)*x(3);
  rhs(3) = k(3)*x(1) - k(5)*x(3) - k(6)*x(2)*x(3);
end%function

%
% deterministic dynamics
%
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s(@hbv_deriv, tout, x0, opts);

%  function xout = stochsim(x0, k, stoiT, tout)
%    nts  = length(tout);
%    tfin = tout(nts);
%    time = tout(1);
%    x = x0;
%    iout = 1;
%    while (time < tfin)
%      r(1) = k(1)*x(1);
%      r(2) = k(2)*x(2);
%      r(3) = k(3)*x(1);
%      r(4) = k(4)*x(1);
%      r(5) = k(5)*x(3);
%      r(6) = k(6)*x(2)*x(3);
%      rtot = sum(r);
%      p=rand(2,1);
%      % choose likely time of next reaction
%      tau = -log(p(1))/rtot;
%      timenew = time + tau;
%      % choose which reaction (mth) is likely to occur
%      rcum = 0;
%      m = 0;
%      while ( rcum <= p(2)*rtot)
%        m = m + 1;
%        rcum = rcum + r(m);
%      end
%      xnew  = x + stoiT(:,m);
%      % check if passing time of requested output
%      while( tout(iout) <= timenew )
%        xout(:,iout) = x;
%        iout = iout + 1;
%        if (iout > nts) break; end
%      end
%      time = timenew;
%      x = xnew;
%    end
%  end%function
%xplot1 = stochsim(x0, k, stoiT, tplot);
%
% check the deterministic steady state and eigenvalues
%
% check parameters for hbv_det simulations
%k(1) = 2;
%k(5) = 1.9985

