function retval = rhs(t,x)
global k1 k_1 k2 k_2 nscheme
c_A   = x(1);
c_B   = x(2);
c_C   = x(3);
r1  = k1*c_A - k_1*c_B;
r2  = k2*c_B - k_2*c_C;
retval = zeros (3, 1);
if (nscheme == 0)
   %
   % full model
   %
   retval(1) = -r1;
   retval(2) = r1 - r2;
   retval(3) = r2;
elseif (nscheme == 1)
   %
   % reaction 1 is rls, reaction 2 at equilibrium
   %
   K2    = k2/k_2;
   retval(1) = -r1;
   retval(2) =  1/(1+K2)*r1;
   retval(3) =  K2/(1+K2)*r1;
elseif (nscheme == 2)
  %
  % reaction 2 is rls, reaction 1 at equilibrium
  %
  K1    = k1/k_1;
  retval(1) = -1/(1+K1) * r2;
  retval(2) = -K1/(1+K1) * r2;
  retval(3) = r2;
elseif (nscheme == 3)
  %
  % QSSA on B, redefine the c_B concentration under QSSA
  %
  c_B= k1/(k_1+k2)*c_A + k_2/(k_1+k2)*c_C;
  r1  = k1*c_A - k_1*c_B;
  r2  = k2*c_B - k_2*c_C;
  retval(1) = -r1;
  %retval(2) = r1 - r2; don't use this one, it is always zero and
  %therefore incorrect
  retval(2) = k1*k2*(k_2-k1)/(k_1+k2)^2 * c_A +  ...
              k_1*k_2*(k1-k_2)/(k_1+k2)^2*c_C;
  retval(3) = r2;
else
  error ('nscheme out of range');
end
