% Copyright (C) 2001, James B. Rawlings and John G. Ekerdt
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2, or (at
% your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; see the file COPYING.  If not, write to
% the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
% MA 02111-1307, USA.

global k_m T_m E c_Af c_A C_ps T_f DeltaH_R U T_a
%
%
% compute the van Heerden diagram showing heat generation and heat
% removal to explain steady-state multiplicity
% jbr, 4/1/98
% jbr, updated, 12/28/2017
%
% units are kmol, min, kJ, K, m^3
%
%
k_m      = 0.001;
T_m      = 298;
E        = 8000;
c_Af     = 2;
C_p      = 4;
rho      = 1000;
C_ps     = rho*C_p;
T_f      = 298;
T_a      = T_f;
DeltaH_R = -3e5;
U        = 0;

thetavec = [30.9, 15, 1.79];
ntheta = length(thetavec);
nTs = 50;
T_vec = linspace(275, 500, nTs)';
k     = k_m*exp(-E*(1./T_vec - 1/T_m));
for i = 1:ntheta
  theta = thetavec(i);
  Qremoval = C_ps/theta*(T_vec - T_f);
  Qgenerated = k./(1+k*theta)*c_Af*(-DeltaH_R);
  table(i) = {[T_vec Qremoval Qgenerated]};
end


%save -ascii vanheerden_1.dat table;

save vanheerden.dat table;

if (~ strcmp (getenv ('OMIT_PLOTS'), 'true')) % PLOTTING
  for i = 1:ntheta
    figure()
    plot (table{i}(:,1),table{i}(:,2:3));
  end
% TITLE
end % PLOTTING