% Copyright (C) 2001, James B. Rawlings and John G. Ekerdt
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2, or (at
% your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; see the file COPYING.  If not, write to
% the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
% MA 02111-1307, USA.

global k_m T_m E c_Af theta C_ps T_f DeltaH_R U T_a Kc T_fs T_set
%
% limit cycle parameters
%
% units are kmol, min, kJ, K, m^3
%
k_m      = 0.004;
T_m      = 298;
E        = 15000;
c_Af     = 2;
C_p      = 4;
rho      = 1000;
C_ps     = C_p*rho;
T_f      = 298;
T_a      = T_f;
DeltaH_R = -2.2e5;
U        = 340;
theta    = 35;
T_set    = 321.53;
c_set    = 0.48995;
T_fs     = T_f;
Kc       = 0;
gamma    = E/T_f;
B        = -DeltaH_R*c_Af*gamma/(C_ps*T_f);
beta     = U/C_ps*theta;
Da       = k_m*exp(-E*(1/T_f-1/T_m))*theta;
x2c      = (T_a-T_f)/T_f*gamma;


%
% compute 5 dynamic trajectories to show phase portrait
%

%x0=[c_set;T_set];
x0=[c_Af;T_f];
tfinal = 5*theta;
ntimes = 200;
tout   = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@rhs, tout, x0,opts);
u = (x(:,2) - T_set)*Kc + T_fs;
conv = (c_Af - x(:,1)) / c_Af;
table = [conv x(:,2)];

x0=[0; T_f];
tfinal = 5*theta;
ntimes = 200;
tout   = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@rhs, tout, x0, opts);
u = (x(:,2) - T_set)*Kc + T_fs;
conv = (c_Af - x(:,1)) / c_Af;
table = [table conv x(:,2)];

x0=[0.3980; 321.39];   %x=0.8010, the unstable steady state IC
tfinal = 5*theta;
ntimes = 200;
tout   = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@rhs, tout, x0, opts);
u = (x(:,2) - T_set)*Kc + T_fs;
conv = (c_Af - x(:,1)) / c_Af;
table = [table conv x(:,2)];

x0=[.8, 310];
tfinal = 5*theta;
ntimes = 200;
tout   = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@rhs, tout, x0, opts);
u = (x(:,2) - T_set)*Kc + T_fs;
conv = (c_Af - x(:,1)) / c_Af;
table = [table conv x(:,2)];

x0=[.6, 315];
tfinal = 5*theta;
ntimes = 200;
tout   = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@rhs, tout, x0, opts);
u = (x(:,2) - T_set)*Kc + T_fs;
conv = (c_Af - x(:,1)) / c_Af;
table = [table conv x(:,2)];

save -ascii phase_portrait.dat table;


if (~ strcmp (getenv ('OMIT_PLOTS'), 'true')) % PLOTTING
plot (table(:,2),table(:,1),table(:,4),table(:,3),...
         table(:,6),table(:,5),table(:,8),table(:,7),...
         table(:,10),table(:,9));
% TITLE
end % PLOTTING