% Copyright (C) 2001, James B. Rawlings and John G. Ekerdt
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2, or (at
% your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; see the file COPYING.  If not, write to
% the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
% MA 02111-1307, USA.

global k_m T_m E c_Af theta C_ps T_f DeltaH_R U T_a Kc T_fs T_set
%
% limit cycle parameters
%
% units are kmol, min, kJ, K, m^3
%
k_m      = 0.004;
T_m      = 298;
E        = 15000;
c_Af     = 2;
C_p      = 4;
rho      = 1000;
C_ps     = C_p*rho;
T_f      = 298;
T_a      = T_f;
DeltaH_R = -2.2e5;
U        = 340;
%theta    = 72.3308;
theta    = 73.1;
T_set    = 321.53;
c_set    = 0.48995;
T_fs     = T_f;
Kc       = 0;
gamma    = E/T_f;
B        = -DeltaH_R*c_Af*gamma/(C_ps*T_f);
beta     = U/C_ps*theta;
Da       = k_m*exp(-E*(1/T_f-1/T_m))*theta;
x2c      = (T_a-T_f)/T_f*gamma;

% find the stable limit cycle
x0=[(1-0.8)*c_Af 310];
tfinal = 40*theta;
ntimes = 3;
tout  = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@rhs, tout, x0, opts);
% now go around the limit cycle once with many time points
x0=x(end,:);
ntimes=200;
tfinal=3*theta;
tout  = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@rhs, tout, x0, opts);
u = (x(:,2) - T_set)*Kc + T_fs;
conv = (c_Af - x(:,1)) / c_Af;
stablim = [tout' x conv u];
%
% reverse time and stabilize the unstable limit cycle starting in the
% interior
%
% find the unstable limit cycle
% 73.4957904330517 305.839679413557 0.516502467355002 -0.00139021373543844 0.0329582458327707 -0.00139021373543844 -0.0329582458327707 1
% stable steady state is about 0.5165, 305.83
%
x0=[(1-0.7)*c_Af; 305];
tfinal = 40*theta;
ntimes = 3;
tout   = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@reverserhs, tout, x0, opts);
% now go around the unstable limit cycle once with many time points
x0=x(end,:);
tfinal = 3*theta;
ntimes = 200;
tout   = linspace(0, tfinal, ntimes);
opts = odeset ('AbsTol', sqrt (eps), 'RelTol', sqrt (eps));
[tsolver, x] = ode15s (@reverserhs, tout, x0, opts);
u = (x(:,2) - T_set)*Kc + T_fs;
conv = (c_Af - x(:,1)) / c_Af;
unstablim = [tout' x conv u];

table = [stablim unstablim];
save -ascii phase_portrait_2.dat table;

if (~ strcmp (getenv ('OMIT_PLOTS'), 'true')) % PLOTTING
plot (table(:,3),table(:,4),table(:,8),table(:,9));
% TITLE
end % PLOTTING