% Copyright (C) 2001, James B. Rawlings and John G. Ekerdt
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2, or (at
% your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; see the file COPYING.  If not, write to
% the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
% MA 02111-1307, USA.

%
% added log transformation in pellet
% jbr
% 12/13/03

global  npts A Aint Bint Rint caf cbf ccf ...
        k10 E1 k20 E2 Ka0 Ea Kc0 Ec Da Db Dc T ...
        Ra Rb Rc Da Db Dc kma kmb kmc dcadr dcbdr dccdr ...
        epsb a T Ntfin Nafin Ncfin Pin Tin Qin Q Cptot U ...
        Ta Rt delH1 delH2 km Rp vis massf Ac xc Pext

Rg  = 8.314;  % J/K mol
Mair= 28.96; % g/mol, mol weight air
%Pin   = 1.5*1.013e5;  % N/m^2
Pin   = 2.0*1.013e5;  % N/m^2
Pext  = 1.013e5; % minimum allowed exit pressure
Tin   = 550; % K
Rt  = 10/2; %cm, tube radius
At  = pi*Rt*Rt; % cm^2, tube cross-sectional area
Ta  = 325; % K, ambient temperature
U    = 5.5e-3; % cal/(cm^2 K s), heat transfer coefficient
delH1 = (-67.63e3); % cal/mol CO;
delH2 = (-460.4e3); % cal/mol C_3H_6;
Cp  = 0.25; % cal/(g K), heat capacity of air
vis = 0.028e-2; % g/(cm s), viscosity of air
bt  = 1; % bed to tube area ratio
%u   = 500/bt;  % cm/sec, feed gas velocity entering bed
u  = 75/bt;  % cm/sec, feed gas velocity entering bed
Ac  = bt*At;  % cm^2 area of bed, 4 x area of tube
Qin = u*Ac;  % cm^3/sec, feed volumetric flowrate
P   = Pin;
T   = Tin;
Q   = Qin;
cfin= P/(Rg*T)*1e-6; % mol/cm^3
Rp  = 0.175; % cm radius of catalyst particle
a   = Rp/3;
rhob = 0.51; % g/cm^3 bed density
rhop = 0.68; % g/cm^3 particle density
epsb = 1 - rhob/rhop; % bed porosity, dimensionless
%epsb = 0.4;
xc  = 0.996;

cafin = cfin*0.02;
cbfin = cfin*0.03;
ccfin = cfin*5e-4;

Nafin = Q*cafin;
Nbfin = Q*cbfin;
Ncfin = Q*ccfin;
Nfin  = [Nafin; Nbfin; Ncfin];
Ntfin = Q*cfin;
massf = Ntfin*Mair; % mass flowrate, g/s, remains constant
Cptot = massf*Cp;

alpha = 1;
k10  = alpha*6.802e16*2.6e6*80/100*0.05/100;  %mol/cm^3 s
k20  = alpha*1.416e18*2.6e6*80/100*0.05/100;  %mol/cm^3 s
E1   = 13108; %K
E2   = 15109; %K
Ka0  = 8.099e6; % cm^3/mol
Kc0  = 2.579e8; % cm^3/mol
Ea   = - 409; %K
Ec   = 191; %K
Da   = 0.0487; % cm^2/s
Db   = 0.0469; % cm^2/s
Dc   = 0.0487; % cm^2/s
kma  = 0.4*9.76;   % cm/s
kmb  = 0.4*10.18;  % cm/s
kmc  = 0.4*9.76;   % cm/s

%
% calculate initial reaction rates
%
k1      = k10*exp(-E1/Tin);
k2      = k20*exp(-E2/Tin);
Ka      = Ka0*exp(-Ea/Tin);
Kc      = Kc0*exp(-Ec/Tin);
den     = (1+Ka*cafin+Kc*ccfin)*(1+Ka*cafin+Kc*ccfin);
r1      = k1*cafin*cbfin/den;
r2      = k2*ccfin*cbfin/den;
%
% adiabatic temperature rise and
% Ucrit to achieve a zero intial temperature derivative
%
adrise = -(cafin*delH1+ccfin*delH2)/(Cp*cfin*Mair)
Ucrit  = (r1*delH1 + r2*delH2)/(2/Rt*(Ta-T))

%
% global collocation
%
npts = 40;
[R A B Q] = colloc(npts-2, 'left', 'right');
R = R*Rp;
A = A/Rp;
B = B/(Rp*Rp);
Q = Q*Rp;
Aint = A(2:npts-1,:);
Bint = B(2:npts-1,:);
Rint = R(2:npts-1);

%
% find the pellet profile at tube inlet
%
caf = cafin; cbf=cbfin; ccf=ccfin;
zain = log(1e-9*caf); zaout = log(0.75*caf);
%zain = log(1e-12*caf); zaout = log(0.9*caf); %P=1.5
za0 = zain + R/Rp*(zaout-zain);
zbin = log(0.75*cbf); zbout = log(cbf);
zb0 = zbin + R/Rp*(zbout-zbin);
zcin = log(1e-6*ccf); zcout = log(ccf);
%zcin = log(1e-9*ccf); zcout = log(0.9*ccf); %P=1.5
zc0 = zcin + R/Rp*(zcout-zcin);

z0 = [za0;zb0;zc0];
fsolve_options = optimset ('TolFun', 1e-16, 'TolX', 1e-10);
[z,fval,info] = fsolve('pellet',z0,fsolve_options);
fsolve_failed = info <= 0;

if (fsolve_failed)
  plot(R,[z0(1:npts),z(1:npts),z0(npts+1:2*npts),z(npts+1:2*npts), ...
          z0(2*npts+1:3*npts),z(2*npts+1:3*npts)])
  error ('cannot find pellet profile at tube inlet')
end

za = z(1:npts);
zb = z(npts+1:2*npts);
zc = z(2*npts+1:3*npts);

ca = exp(za);
cb = exp(zb);
cc = exp(zc);

%
% march down the bed
%
nvs    = 201;
%vfinal = 4737;
vfinal = 2000;
vsteps = linspace (0,vfinal,nvs)';
vout   = vsteps;
y0     = [Nfin; Tin; Pin; z];
ydot0    = zeros(length(y0),1);
res      = bed(0,y0,ydot0);
ydot0(1:5)    = -res(1:5);

ymin = min(y0);
opts = odeset ('RelTol', 1e-10, 'AbsTol', 1e-10, 'Events', @stop);
t0=cputime();
[vout,y] = ode15i (@bed, vsteps, y0, ydot0, opts);
cpu = cputime()-t0
nout = length(vout);
if ( nout == nvs )
  fprintf ('hey, did not reach final conversion, increase vfinal\n');
end
xa = (Nafin-y(end,1))/Nafin
xb = (Nbfin-y(end,2))/Nbfin
xc = (Ncfin-y(end,3))/Ncfin
P=y(:,5);
T=y(:,4);
ctot = P./(Rg*T)*1e-6;
Nt = Ntfin - 1/2*(Nafin-y(:,1))+1/2*(Ncfin-y(:,3));
Q = Nt./ctot;
caf = y(:,1)./Q;
cbf = y(:,2)./Q;
ccf = y(:,3)./Q;
Patm = P/1.013e5;
table1 = [vout, caf, cbf, ccf, T, Patm];
%
% pick out some good length locations for pellet profiles
%
nrows = 5;
%rowsp = ceil(linspace(1,nout,nrows));
rowsp = [1,5,10,50,90,100,nout]
vout(rowsp)
cols = [6:npts+5];
ca   = exp(y(rowsp,cols)');
cols = [npts+6:2*npts+5];
cb   = exp(y(rowsp,cols)');
cols = [2*npts+6:3*npts+5];
cc   = exp(y(rowsp,cols)');
table2 = [R, ca, cb, cc];

save multicolloc_log.dat table1 table2;

if (~ strcmp (getenv ('OMIT_PLOTS'), 'true')) % PLOTTING
subplot (2, 2, 1);
semilogy (table1(:,1), table1(:,2:4));
% TITLE multicolloc_log_1

subplot (2, 2, 2);
plot (table1(:,1), table1(:,5));
% TITLE multicolloc_log_2

subplot (2, 2, 4);
plot (table1(:,1), table1(:,6));
% TITLE multicolloc_log_2

subplot (2, 2, 3);
semilogy (table2(:,1), table2(:,2:8));
% TITLE multicolloc_log_3
end % PLOTTING